@@ -243,9 +243,9 @@ def preset_menu(preset_id):
     row.eb.connect("button-press-event", set_up_dock_tab, preset, preset_name)
     list_box.add(row)
 
-    row = SideMenuRow(voc["exit-menu"], margin_start=18)
-    row.eb.connect("button-press-event", set_up_bar_tab, preset, preset_name)
-    list_box.add(row)
+    # row = SideMenuRow(voc["exit-menu"], margin_start=18)
+    # row.eb.connect("button-press-event", set_up_bar_tab, preset, preset_name)
+    # list_box.add(row)
 
     row = SideMenuRow(voc["notifications"], margin_start=18)
     row.eb.connect("button-press-event", set_up_notification_tab, preset, preset_name)
@@ -289,7 +289,7 @@ def set_up_screen_tab(*args):
     global content
     content.destroy()
     global update_btn
-    content, update_btn = screen_tab(settings, voc, pending_updates)
+    content = screen_tab(settings, voc)
     grid.attach(content, 1, 0, 1, 1)
 
 
@@ -389,12 +389,12 @@ def set_up_dock_tab(event_box, event_button, preset, preset_name):
     grid.attach(content, 1, 0, 1, 1)
 
 
-def set_up_bar_tab(event_box, event_button, preset, preset_name):
-    hide_submenus()
-    global content
-    content.destroy()
-    content = bar_tab(preset, preset_name, voc)
-    grid.attach(content, 1, 0, 1, 1)
+# def set_up_bar_tab(event_box, event_button, preset, preset_name):
+#     hide_submenus()
+#     global content
+#     content.destroy()
+#     content = bar_tab(preset, preset_name, voc)
+#     grid.attach(content, 1, 0, 1, 1)
 
 
 def set_up_notification_tab(event_box, event_button, preset, preset_name):
@@ -709,6 +709,9 @@ def save_includes():
     if preset["dock-exclusive"]:
         cmd_dock += " -x"
 
+    if preset["launcher-at-start"]:
+        cmd_dock += " -lp start"
+
     if "preset-" in settings["panel-preset"]:
         cmd_dock += " -s {}.css".format(settings["panel-preset"])
     elif preset["dock-css"]:
@@ -718,7 +721,6 @@ def save_includes():
         includes.append("$dock = {}".format(cmd_dock))
 
     includes.append("\n# AUTOSTART")
-    includes.append("exec-once = rm {}".format(os.path.join(temp_dir(), "nwg-shell-check-update.lock")))
 
     # Kill wlsunset. We will need either to restart it or turn it off
     subprocess.call("pkill -f wlsunset", shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT)
@@ -730,6 +732,10 @@ def save_includes():
                                                               settings["night-lat"],
                                                               settings["night-long"],
                                                               settings["night-gamma"])
+        if settings["night-outputs"]:
+            for output in settings["night-outputs"]:
+                cmd += " -o {}".format(output)
+
         try:
             subprocess.Popen(cmd, shell=True)
         except Exception as e:
@@ -763,8 +769,6 @@ def save_includes():
     if preset["dock-on"] and (preset["dock-autohide"] or preset["dock-permanent"]):
         includes.append(cmd_dock)
 
-    includes.append("exec = nwg-shell-check-updates")
-
     if settings["lockscreen-use-settings"]:
         c_sleep = "timeout {} '{}'".format(settings["sleep-timeout"], settings["sleep-cmd"]) if settings[
             "sleep-cmd"] else ""
@@ -825,6 +829,8 @@ def save_includes():
             includes.append('    no_cursor_warps = {}'.format(bool2lower(settings["gen-no_cursor_warps"])))
         if settings["gen-no_focus_fallback"]:
             includes.append('    no_focus_fallback = {}'.format(bool2lower(settings["gen-no_focus_fallback"])))
+        if settings["gen-allow_tearing"]:
+            includes.append('    allow_tearing = {}'.format(bool2lower(settings["gen-allow_tearing"])))
         if settings["gen-resize_on_border"]:
             includes.append('    resize_on_border = {}'.format(bool2lower(settings["gen-resize_on_border"])))
         if settings["gen-extend_border_grab_area"]:
@@ -844,7 +850,6 @@ def save_includes():
         includes.append('    smart_resizing = {}'.format(bool2lower(settings["dwindle-smart_resizing"])))
         includes.append('    special_scale_factor = {}'.format(settings["dwindle-special_scale_factor"]))
         includes.append('    split_width_multiplier = {}'.format(settings["dwindle-split_width_multiplier"]))
-        includes.append('    no_gaps_when_only = {}'.format(bool2lower(settings["dwindle-no_gaps_when_only"])))
         includes.append('    use_active_for_splits = {}'.format(bool2lower(settings["dwindle-use_active_for_splits"])))
         includes.append('    default_split_ratio = {}'.format(settings["dwindle-default_split_ratio"]))
         includes.append('}')
@@ -857,10 +862,9 @@ def save_includes():
         includes.append('    mfact = {}'.format(settings["master-mfact"]))
         # includes.append('    new_is_master = {}'.format(bool2lower(settings["master-new_is_master"])))
         includes.append('    new_on_top = {}'.format(bool2lower(settings["master-new_on_top"])))
-        includes.append('    no_gaps_when_only = {}'.format(bool2lower(settings["master-no_gaps_when_only"])))
         includes.append('    orientation = {}'.format(settings["master-orientation"]))
         includes.append('    inherit_fullscreen = {}'.format(bool2lower(settings["master-inherit_fullscreen"])))
-        includes.append('    always_center_master = {}'.format(bool2lower(settings["master-always_center_master"])))
+        includes.append('    slave_count_for_center_master = {}'.format(settings["master-slave_count_for_center_master"]))
         includes.append('}')
 
     # Export input devices settings
@@ -946,11 +950,19 @@ def save_includes():
     if preset["launcher-super-key"]:
         includes.append('bindr = SUPER, SUPER_L, exec, $launcher')
 
+    includes.append('\n# LAYER RULES')
+    if preset["launcher-blur-background"]:
+        includes.append("layerrule = blur, nwg-drawer")
+    if preset["dock-blur-background"]:
+        includes.append("layerrule = blur, nwg-dock")
+
     p = os.path.join(config_home, "hypr/includes.conf")
+
+    reload()
+
     print("Saving includes to {}".format(p))
     save_list_to_text_file(includes, p)
 
-    reload()
 
 
 def reload():
@@ -987,6 +999,7 @@ def load_settings():
         "night-temp-high": 6500,
         "night-gamma": 1.0,
         "night-on": True,
+        "night-outputs": [],
         "terminal": "",
         "file-manager": "",
         "editor": "",
@@ -1020,6 +1033,7 @@ def load_settings():
         "gen-resize_on_border": False,
         "gen-extend_border_grab_area": 15,
         "gen-hover_icon_on_border": True,
+        "gen-allow_tearing": False,
 
         "dwindle-use-settings": True,
         "dwindle-pseudotile": False,
@@ -1030,7 +1044,6 @@ def load_settings():
         "dwindle-permanent_direction_override": False,
         "dwindle-special_scale_factor": 0.8,
         "dwindle-split_width_multiplier": 1.0,
-        "dwindle-no_gaps_when_only": False,
         "dwindle-use_active_for_splits": True,
         "dwindle-default_split_ratio": 1.0,
 
@@ -1040,10 +1053,9 @@ def load_settings():
         "master-mfact": 0.55,
         "master-new_is_master": True,
         "master-new_on_top": False,
-        "master-no_gaps_when_only": False,
         "master-orientation": "left",
         "master-inherit_fullscreen": True,
-        "master-always_center_master": False,
+        "master-slave_count_for_center_master": 2,
 
         "input-use-settings": True,
         "input-kb_layout": "us",
@@ -1103,6 +1115,10 @@ def load_settings():
         "unsplash-width": 1920,
         "unsplash-height": 1080,
         "unsplash-keywords": ["nature", "water", "landscape"],
+        "wallhaven-ratio": "16x9,16x10",
+        "wallhaven-atleast": "1920x1080",
+        "wallhaven-api-key": "",
+        "wallhaven-tags": ["nature", "landscape"],
         "help-font-size": 12,
         "help-layer-shell": True,
         "help-keyboard": False,
@@ -1155,6 +1171,7 @@ def load_presets():
 def load_preset(file_name):
     defaults = {
         "panel-css": "",
+        "launcher-at-start": False,
         "launcher-columns": 6,
         "launcher-icon-size": 64,
         "launcher-file-search-columns": 2,
@@ -1170,6 +1187,7 @@ def load_preset(file_name):
         "launcher-run-through-compositor": False,
         "launcher-super-key": False,
         "launcher-output": "Any",
+        "launcher-blur-background": False,
         "exit-position": "center",
         "exit-full": False,
         "exit-alignment": "middle",
@@ -1191,6 +1209,7 @@ def load_preset(file_name):
         "dock-startup-delay": 0,
         "dock-css": "",
         "dock-on": False,
+        "dock-blur-background": False,
         "swaync-positionX": "right",
         "swaync-positionY": "top",
         "swaync-control-center-width": 500,
